ImageSource
===========

.. currentmodule:: toasty.pipeline

.. autoclass:: ImageSource
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ImageSource.deserialize
      ~ImageSource.fetch_candidate
      ~ImageSource.get_config_key
      ~ImageSource.process
      ~ImageSource.query_candidates

   .. rubric:: Methods Documentation

   .. automethod:: deserialize
   .. automethod:: fetch_candidate
   .. automethod:: get_config_key
   .. automethod:: process
   .. automethod:: query_candidates
